OpenTraining
============

A set of `Sphinx <https://www.sphinx-doc.org/>`__ extensions that help
maintain training material.

Examples:

* `Python: The Language Fundamentals
  <https://www.faschingbauer.me/trainings/material/soup/python/basics/group.html>`__
* `Python: More Language Features
  <https://www.faschingbauer.me/trainings/material/soup/python/advanced/group.html>`__
* `Python: Project/Package Management
  <https://www.faschingbauer.me/trainings/material/soup/python/swdev/group.html>`__
* `Linux Driver Development
  <https://www.faschingbauer.me/trainings/material/soup/kernel/index.html>`__

Read documentation on `ReadTheDocs <opentraining.readthedocs.io>`__.
